@@ -1,6 +1,5 @@
 from dataclasses import dataclass
-from typing import List
-
+from typing import Coroutine
 from etsy_apiv3.utils import EtsySession, Response
 from etsy_apiv3.models import Receipt, ReceiptType, Transaction
 
@@ -52,6 +51,11 @@ class ReceiptResource:
         
         return Receipt(**json)
 
+    async def aget_receipt_by_id(self, shop_id: int, receipt_id: int) -> Coroutine:
+        endpoint = f"shops/{shop_id}/receipts/{receipt_id}"
+        json = self.session.async_request(endpoint=endpoint)
+        return Receipt(**json)
+    
     def create_shipment(self, shop_id: int, receipt_id: int, tracking_number: str, carrier_name: str, send_bcc: bool = True, note_to_buyer: str = "") -> Receipt:
         """
         Adds tracking information to the receipt object
@@ -112,4 +116,4 @@ class ReceiptResource:
             "offset": offset
         }
         response = self.session.request(endpoint, params=params)
-        return Response[Transaction](**response)
\ No newline at end of file
+        return Response[Transaction](**response)
