@@ -1,4 +1,5 @@
 from typing import Optional, Callable
+from httpx import AsyncClient
 from requests_oauthlib import OAuth2Session
 from async_oauthlib import OAuth2Session as AsyncOAuth2Session
 import requests
@@ -34,12 +35,13 @@ class EtsySession:
             
             self.__refresh_url = "https://api.etsy.com/v3/public/oauth/token"
             self.__oauth2_session = self.__create_oath2_session()
+            self.__async_session = self.__create_async_oauth2_session()
             self.__me = Me(**self.request(f"users/me"))
 
         else:
             self.__oauth2_session = requests.Session()
-            
-        
+            self.__async_session = AsyncClient()
+
     def __create_oath2_session(self) -> OAuth2Session:
         refresh_kwargs = {
             'client_id': self.CLIENT_KEY,
@@ -51,6 +53,18 @@ class EtsySession:
                                 )
         return session
 
+    def __create_async_oauth2_session(self) -> AsyncOAuth2Session:
+        refresh_kwargs = {
+            'client_id': self.CLIENT_KEY,
+            'client_secret': self.CLIENT_SECRET,
+        }
+
+        session = AsyncOAuth2Session(
+            self.CLIENT_KEY, token=self.TOKEN, auto_refresh_kwargs=refresh_kwargs,
+            auto_refresh_url=self.__refresh_url, token_updater=self.token_updater
+        )
+        return session
+    
     @property
     def me(self) -> Me:
         return self.__me
@@ -87,14 +101,13 @@ class EtsySession:
 
         return self.create_response(req)
 
-    async def async_request(self, session: AsyncOAuth2Session, endpoint: str, method="GET", headers: Optional[dict] = None, *args, **kwargs) -> dict:
+    async def async_request(self, endpoint: str, method="GET", headers: Optional[dict] = None, *args, **kwargs) -> dict:
         url = f"{self.__base_endpoint}{endpoint}"
         if headers is None:
             headers = {"x-api-key": self.CLIENT_KEY}
 
-        req: requests.Response = await session.get(url=url, headers=headers, *args, **kwargs)
-        print(req.text)
-        json: dict = await req.json()
+        req = await self.__async_session.request(method=method, url=url, headers=headers, *args, **kwargs)
+        json = await req.json()
 
         if "error" in json.keys():
             raise EtsyRequestException(req.status_code, json["error"])
